#
# spec file for package google-perftools
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# needsrootforbuild


Name:           google-perftools
Version:        1.9.1
Release:        1.3
Group:          System/Libraries
License:        BSD-3-Clause
Url:            http://goog-perftools.sourceforge.net
Source0:        %{name}-%{version}.tar.bz2
Patch4:         %{name}-fix_docdir.patch
Patch11:        %{name}_fix_multiple_install_headers.patch
Patch12:        %{name}_fix_unassigned_malloc_in_unittest.patch
Patch14:        %{name}_gcc46.patch
BuildRequires:  gcc-c++ pkg-config
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  automake
# Can't use libunwind.  See bnc#393927 and bnc#395623
%ifarch x86_64 ia64 ppc ppc64 s390 s390x
%define no_libunwind_on_64 "-DNO_TCMALLOC_SAMPLES"
%define no_libunwind_on_64_config "--enable-frame-pointers"
%else
%define no_libunwind_on_64 ""
%define no_libunwind_on_64_config ""
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Performance Tools for C++

%description
The google-perftools packages contain some utilities to improve and
analyze the performance of C++ programs. This includes an optimized
thread-caching malloc() and cpu and heap profiling utilities.



%package devel
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Summary:        Performance tools for C++
Requires:       libstdc++-devel, google-perftools = %{version}

%description devel
The google-perftools-devel package contains static and debug libraries
and header files for developing applications that use the
google-perftools package.



%prep
%setup -q
%patch4 -p1
%patch11 -p1
%patch12 -p1
%patch14 -p1

%build
autoreconf -fi
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing %no_libunwind_on_64" \
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing %no_libunwind_on_64" \
%configure --disable-static --with-gnu-ld --with-pic %no_libunwind_on_64_config
%{__make} %{?jobs:-j%jobs}

%install
make DESTDIR=$RPM_BUILD_ROOT install
%{__rm} -f %{buildroot}%{_libdir}/*.la

%clean 
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
/usr/bin/pprof
%_libdir/libprofiler.so.0*
# %_libdir/libstacktrace.so.0*   # libstacktrace.so got removed in 0.96
%_libdir/libtcmalloc.so.0*
%_libdir/libtcmalloc_debug.so.0*
%_libdir/libtcmalloc_minimal.so.0*
%_libdir/libtcmalloc_minimal_debug.so.0*
%_libdir/libtcmalloc_and_profiler.so.0*
%_mandir/man1/pprof.1.gz
%dir %attr(775,root,root) /usr/share/doc/packages/%{name}
/usr/share/doc/packages/%{name}/AUTHORS
/usr/share/doc/packages/%{name}/COPYING
/usr/share/doc/packages/%{name}/ChangeLog
/usr/share/doc/packages/%{name}/INSTALL
/usr/share/doc/packages/%{name}/NEWS
/usr/share/doc/packages/%{name}/README
/usr/share/doc/packages/%{name}/TODO
/usr/share/doc/packages/%{name}/README_windows.txt
/usr/share/doc/packages/%{name}/cpuprofile.html
/usr/share/doc/packages/%{name}/cpuprofile-fileformat.html
/usr/share/doc/packages/%{name}/designstyle.css
/usr/share/doc/packages/%{name}/heapprofile.html
/usr/share/doc/packages/%{name}/pprof_remote_servers.html
/usr/share/doc/packages/%{name}/heap-example1.png
/usr/share/doc/packages/%{name}/heap_checker.html
/usr/share/doc/packages/%{name}/index.html
/usr/share/doc/packages/%{name}/overview.dot
/usr/share/doc/packages/%{name}/overview.gif
/usr/share/doc/packages/%{name}/pageheap.dot
/usr/share/doc/packages/%{name}/pageheap.gif
/usr/share/doc/packages/%{name}/pprof-test-big.gif
/usr/share/doc/packages/%{name}/pprof-test.gif
/usr/share/doc/packages/%{name}/pprof-vsnprintf-big.gif
/usr/share/doc/packages/%{name}/pprof-vsnprintf.gif
/usr/share/doc/packages/%{name}/spanmap.dot
/usr/share/doc/packages/%{name}/spanmap.gif
/usr/share/doc/packages/%{name}/t-test1.times.txt
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.1024.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.128.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.131072.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.16384.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.2048.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.256.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.32768.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.4096.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.512.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.64.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.65536.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspercpusec.vs.threads.8192.bytes.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.1.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.12.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.16.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.2.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.20.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.3.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.4.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.5.threads.png
/usr/share/doc/packages/%{name}/tcmalloc-opspersec.vs.size.8.threads.png
/usr/share/doc/packages/%{name}/tcmalloc.html
/usr/share/doc/packages/%{name}/threadheap.dot
/usr/share/doc/packages/%{name}/threadheap.gif

%files devel
%defattr(-,root,root)
%dir %attr(775,root,root) /usr/include/google
/usr/include/google/heap-checker.h
/usr/include/google/heap-profiler.h
/usr/include/google/malloc_extension.h
/usr/include/google/malloc_extension_c.h
/usr/include/google/malloc_hook.h
/usr/include/google/malloc_hook_c.h
/usr/include/google/profiler.h
/usr/include/google/stacktrace.h
/usr/include/google/tcmalloc.h
%_libdir/libprofiler.so
# %_libdir/libstacktrace.*a    # libstacktrace.so got removed in 0.96
# %_libdir/libstacktrace.so    # libstacktrace.so got removed in 0.96
%_libdir/libtcmalloc.so
%_libdir/libtcmalloc_debug.so
%_libdir/libtcmalloc_minimal.so
%_libdir/libtcmalloc_minimal_debug.so
%_libdir/libtcmalloc_and_profiler.so
%_libdir/pkgconfig/libprofiler.pc
%_libdir/pkgconfig/libtcmalloc.pc
%_libdir/pkgconfig/libtcmalloc_debug.pc
%_libdir/pkgconfig/libtcmalloc_minimal.pc
%_libdir/pkgconfig/libtcmalloc_minimal_debug.pc

%changelog
* Sat Dec 24 2011 cgardner@suse.com
- Version 1.9.1, released 23 Dec 2011.
  * google-perftools: version 1.9 release
  * Lightweight check for double-frees (blount)
  * BUGFIX: Fix pprof to exit properly if run with no args (dagitses)
  * Suggest ASan as a way to diagnose buggy code (ppluzhnikov)
  * Get rid of unused CACHELINE_SIZE (csilvers)
  * Replace atexit() calls with global dtors; helps freebsd (csilvers)
  * Disable heap-checker under AddressSanitizer (kcc)
  * Fix bug in powerpc stacktracing (ppluzhnikov)
  * PERF: Use exponential backoff waiting for spinlocks (m3b)
  * Fix 64-bit nm on 32-bit binaries in pprof (csilvers)
  * Add ProfileHandlerDisallowForever (rsc)
  * BUGFIX: Shell escape when forking in pprof (csilvers)
  * No longer combine overloaded functions in pprof (csilvers)
  * Fix address-normalizing bug in pprof (csilvers)
  * More consistently call abort() instead of exit() on failure (csilvers)
  * Allow NoGlobalLeaks to be safely called more than once (csilvers)
  * PORTING/BUGFIX: Fix ARM cycleclock to use volatile asm (dougkwan)
  * PORTING: 64-bit atomic ops for ARMv7 (dougkwan)
  * PORTING: Implement stacktrace for ARM (dougkwan)
  * PORTING: Fix malloc_hook_mmap_linux for ARM (dougkwan)
  * PORTING: Update linux_syscall_support.h for ARM/etc (evannier, sanek)
  * PORTING: Fix freebsd to work on x86_64 (chapp...@gmail.com)
  * PORTING: Added additional SYS_mmap fixes for FreeBSD (chappedm)
  * PORTING: Allow us to compile on OS X 10.6 and run on 10.5 (raltherr)
  * PORTING: Check for mingw compilers that *do* define timespec
  * PORTING: Add "support" for MIPS cycletimer
  * PORTING: Fix fallback cycle-timer to work with Now (dougkwan)
  * PERF: Move stack trace collecting out of the mutex (taylorc)
  * PERF: Get the deallocation stack trace outside the mutex (sean)
  * Make PageHeap dynamically allocated for leak checks (maxim)
  * BUGFIX: Fix probing of nm -f behavior in pprof (dpeng)
  * BUGFIX: Fix a race with the CentralFreeList lock before main (sanjay)
  * Support /pprof/censusprofile url arguments (rajatjain)
  * Change IgnoreObject to return its argument (nlewycky)
  * Update malloc-hook files to support more CPUs
  * BUGFIX: write our own strstr to avoid libc problems (csilvers)
  * Use simple callgrind compression facility in pprof
  * Print an error message when we can't run pprof to symbolize (csilvers)
  * Die in configure when g++ is't installed (csilvers)
  * DOC: Beef up the documentation a bit about using libunwind (csilvers)
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Jul 18 2011 cgardner@suse.com
- Version 1.8, released 15 July 2011.
  * PORTING: (Disabled) support for patching mmap on freebsd (chapp...)
  * PORTING: Support volatile __malloc_hook for glibc 2.14 (csilvers)
  * PORTING: Use _asm rdtsc and __rdtsc to get cycleclock in windows (koda)
  * PORTING: Fix fd vs. HANDLE compiler error on cygwin (csilvers)
  * PORTING: Do not test memalign or double-linking on OS X (csilvers)
  * PORTING: Actually enable TLS on windows (jontra)
  * PORTING: Some work to compile under Native Client (krasin)
  * PORTING: deal with pthread_once w/o -pthread on freebsd (csilvers)
  * Rearrange libc-overriding to make it easier to port (csilvers)
  * Display source locations in pprof disassembly (sanjay)
  * BUGFIX: Actually initialize allocator name (mec)
  * BUGFIX: Keep track of 'overhead' bytes in malloc reporting (csilvers)
  * Allow ignoring one object twice in the leak checker (glider)
  * BUGFIX: top10 in pprof should print 10 lines, not 11 (rsc)
  * Refactor vdso source files (tipp)
  * Some documentation cleanups
  * Document MAX_TOTAL_THREAD_CACHE_SIZE <= 1Gb (nsethi)
  * Add MallocExtension::GetOwnership(ptr) (csilvers)
  * BUGFIX: We were leaving out a needed $(top_srcdir) in the Makefile
  * PORTING: Support getting argv0 on OS X
  * Add 'weblist' command to pprof: like 'list' but html (sanjay)
  * Improve source listing in pprof (sanjay)
  * Cap cache sizes to reduce fragmentation (ruemmler)
  * Improve performance by capping or increasing sizes (ruemmler)
  * Add M{,un}mapReplacmenet hooks into MallocHook (ribrdb)
  * Refactored system allocator logic (gangren)
  * Include cleanups (csilvers)
  * Add TCMALLOC_SMALL_BUT_SLOW support (ruemmler)
  * Clarify that tcmalloc stats are MiB (robinson)
  * Remove support for non-tcmalloc debugallocation (blount)
  * Add a new test: malloc_hook_test (csilvers)
  * Change the configure script to be more crosstool-friendly (mcgrathr)
  * PORTING: leading-underscore changes to support win64 (csilvers)
  * Improve debugallocation tc_malloc_size (csilvers)
  * Extend atomicops.h and cyceclock to use ARM V6+ optimized code (sanek)
  * Change malloc-hook to use a list-like structure (llib)
  * Add flag to use MAP_PRIVATE in memfs_malloc (gangren)
  * Windows support for pprof: nul and /usr/bin/file (csilvers)
  * TESTING: add test on strdup to tcmalloc_test (csilvers)
  * Augment heap-checker to deal with no-inode maps (csilvers)
  * Count .dll/.dylib as shared libs in heap-checker (csilvers)
  * Disable sys_futex for arm; it's not always reliable (sanek)
  * PORTING: change lots of windows/port.h macros to functions
  * BUGFIX: Generate correct version# in tcmalloc.h on windows (csilvers)
  * PORTING: Some casting to make solaris happier about types (csilvers)
  * TESTING: Disable debugallocation_test in 'minimal' mode (csilvers)
  * Rewrite debugallocation to be more modular (csilvers)
  * Don't try to run the heap-checker under valgrind (ppluzhnikov)
  * BUGFIX: Make focused stat %%'s relative, not absolute (sanjay)
  * BUGFIX: Don't use '//' comments in a C file (csilvers)
  * Quiet new-gcc compiler warnings via -Wno-unused-result, etc (csilvers)
* Sat Feb  5 2011 cgardner@suse.de
- Version 1.7, from upstream
  * Reduce page map key size under x86_64 by 4.4MB (rus)
  * Remove a flaky malloc-extension test (fdabek)
  * Improve the performance of PageHeap::New (ond..., csilvers)
  * Improve sampling_test with no-inline additions/etc (fdabek)
  * 16-byte align debug allocs (jyasskin)
  * Change FillProcSelfMaps to detect out-of-buffer-space (csilvers)
  * Document the need for sampling to use GetHeapSample (csilvers)
  * Try to read TSC frequency from tsc_freq_khs (adurbin)
  * Do better at figuring out if tests are running under gdb (ppluzhnikov)
  * Improve spinlock contention performance (ruemmler)
  * Better internal-function list for pprof's /contention (ruemmler)
  * Speed up GoogleOnce (m3b)
  * Limit number of incoming/outgoing edges in pprof (sanjay)
  * Add pprof --evince to go along with --gv (csilvers)
  * Document the various ways to get heap-profiling information (csilvers)
  * Separate out synchronization profiling routines (ruemmler)
  * Improve malloc-stats output to be more understandable (csilvers)
  * Add support for census profiler in pporf (nabeelmian)
  * Document how pprof's /symbol must support GET requests (csilvers)
  * Improve acx_pthread.m4 (ssuomi, liujisi)
  * Speed up pprof's ExtractSymbols (csilvers)
  * Ignore some known-leaky (java) libraries in the heap checker (davidyu)
  * Make kHideMask use all 64 bits in tests (ppluzhnikov)
  * Clean up pprof input-file handling (csilvers)
  * BUGFIX: Don't crash if __environ is NULL (csilvers)
  * BUGFIX: Fix totally broken debugallocation tests (csilvers)
  * BUGFIX: Fix up fake_VDSO handling for unittest (ppluzhnikov)
  * BUGFIX: Suppress all large allocs when report threshold is 0 (lexie)
  * BUGFIX: mmap2 on i386 takes an off_t, not off64_t (csilvers)
  * PORTING: Add missing PERFTOOLS_DLL_DECL (csilvers)
  * PORTING: Add stddef.h to make newer gcc's happy (csilvers)
  * PORTING: Document some tricks for working under OS X (csilvers)
  * PORTING: Don't try to check valgrind for windows (csilvers)
  * PORTING: Make array-size a var to compile under clang (chandlerc)
  * PORTING: No longer hook _aligned_malloc and _aligned_free (csilvers)
  * PORTING: Quiet some gcc warnings (csilvers)
  * PORTING: Replace %%PRIxPTR with %%p to be more portable (csilvers)
  * PORTING: Support systems that capitalize /proc weirdly (sanek)
  * PORTING: Treat arm3 the same as arm5t in cycletimer (csilvers)
  * PORTING: Update windows logging to not allocate memory (csilvers)
  * PORTING: avoid double-patching newer windows DLLs (roger.orr)
  * PORTING: get dynamic_annotations.c to work on windows (csilvers)
  * Add pkg-config .pc files for the 5 libraries we produce (csilvers)
  * Added proper libtool versioning, so this lib will be 0.1.0 (csilvers)
  * Moved from autoconf 2.64 to 2.65
* Mon Sep  6 2010 cgardner@novell.com
- Update to 1.6, from upstream.
  * Add tc_malloc_usable_size for compatibility with glibc (csilvers)
  * Override malloc_usable_size with tc_malloc_usable_size (csilvers)
  * Default to no automatic heap sampling in tcmalloc (csilvers)
  * Add -DTCMALLOC_LARGE_PAGES, a possibly faster tcmalloc (rus)
  * Make some functions extern "C" to avoid false ODR warnings (jyasskin)
  * pprof: Add SVG-based output (rsc)
  * pprof: Extend pprof --tools to allow per-tool configs (csilvers)
  * pprof: Improve support of 64-bit and big-endian profiles (csilvers)
  * pprof: Add interactive callgrind suport (weidenri...)
  * pprof: Improve address->function mapping a bit (dpeng)
  * Better detection of when we're running under valgrind (csilvers)
  * Better CPU-speed detection under valgrind (saito)
  * Use, and recommend, -fno-builtin-malloc when compiling (csilvers)
  * Avoid false-sharing of memory between caches (bmaurer)
  * BUGFIX: Fix heap sampling to use correct alloc size (bmauer)
  * BUGFIX: Avoid gcc 4.0.x bug by making hook-clearing atomic (csilvers)
  * BUGFIX: Avoid gcc 4.5.x optimization bug (csilvers)
  * BUGFIX: Work around deps-determining bug in libtool 1.5.26 (csilvers)
  * BUGFIX: Fixed test to use HAVE_PTHREAD, not HAVE_PTHREADS (csilvers)
  * BUGFIX: Fix tls callback behavior on windows when using wpo (wtc)
  * BUGFIX: properly align allocation sizes on Windows (antonm)
  * BUGFIX: Fix prototypes for tcmalloc/debugalloc wrt throw() (csilvers)
  * DOC: Updated heap-checker doc to match reality better (fischman)
  * DOC: Document ProfilerFlush, ProfilerStartWithOptions (csilvers)
  * DOC: Update docs for heap-profiler functions (csilvers)
  * DOC: Clean up documentation around tcmalloc.slack_bytes (fikes)
  * DOC: Renamed README.windows to README_windows.txt (csilvers)
  * DOC: Update the NEWS file to be non-empty (csilvers)
  * PORTING: Fix windows addr2line and nm with proper rc code (csilvers)
  * PORTING: Add CycleClock and atomicops support for arm 5 (sanek)
  * PORTING: Improve PC finding on cygwin and redhat 7 (csilvers)
  * PORTING: speed up function-patching under windows (csilvers)
* Fri Jul  9 2010 cgardner@suse.de
- Update to 1.5, from upstream.
* Mon Feb  8 2010 jengelh@medozas.de
- disable libunwind for SPARC too
- set ExclusiveArch to what the source code actually seems to
  supports (which is much less than there is use of %%ifarch)
* Sat Jun 20 2009 coolo@novell.com
- fix build with automake 1.11
* Sat Apr  4 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Fri Sep 19 2008 cgardner@suse.de
- Update to 0.98.  Builds and runs only on ix86, x86_64 and ppc.
* Wed Oct 24 2007 cgardner@suse.de
- Fix memset calls in test programs for gcc 4.3
* Sun Jun 10 2007 schwab@suse.de
- Fix dependencies.
* Fri Jun  8 2007 cgardner@suse.de
- Fixed build for gcc 4.2 for x86_64.
* Tue Apr 17 2007 cgardner@suse.de
- Fixed build on s390 and s390x.
* Thu Apr  5 2007 cgardner@novell.com
- Bug#260744: Fix location of docs
* Mon Feb 26 2007 cgardner@suse.de
- Fixed errors regarding strcmp()
- Fixed warnings about strict-aliasing
- Fixed _syscallN() to build on x86_64 10.3
- Near Fix to sigcontext struct to build on s390{,x}
* Wed Feb 21 2007 cgardner@novell.com
- Initial submission of 0.8
